
//app e banco são recebidos quando fazemos a chamada
// de rotas_funcionarios
module.exports = function (app, banco) {

  const Funcionario = require("../modelo/Funcionario");
  const JwtToken = require('../modelo/JwtToken');
  const Cargo = require('../modelo/Cargo');
  app.post('/login', (request, response) => {
    console.log("rota: POST: /login");

    const email = request.body.email;
    const senha = request.body.senha;

    const funcionario = new Funcionario(banco);
    funcionario.setEmail(email);
    funcionario.setSenha(senha);

    funcionario.login().then((respostaLogin) => {
      if (respostaLogin.status == true) {
        let usuario = {
          email: respostaLogin.email,
          nome: respostaLogin.nome
        }
        const jwt = new JwtToken();
        const novoToken = jwt.gerarToken(usuario);

        const resposta = {
          status: true,
          msg: "Login efetuado com sucesso",
          token: novoToken,
          funcionario: usuario
        }

        response.status(201).send(resposta);
      } else {
        const resposta = {
          status: false,
          msg: "Usuário não logado",
          codigo: 401,
        }
        response.send(resposta, 404);
      }

    }).catch((erro) => {
      const resposta = {
        status: false,
        msg: 'erro ao executar',
        codigo: '005',
        dados: erro,
      }



      response.status(201).send(erro);
    });
    // return next(e);
    // response.status(201).send("erro");
  });



  /*************************************************************************************************************************** */
  //create
  app.post('/funcionarios', (request, response) => {

    const nome = request.body.nome;
    const email = request.body.email;
    const senha = request.body.senha;
    const recebeValeTransporte = request.body.vt;
    const idCargo = request.body.idCargo;


    const funcionario = new Funcionario(banco);
    funcionario.setNome(nome);
    funcionario.setEmail(email);
    funcionario.setSenha(senha);
    funcionario.setRecebeValeTransporte(recebeValeTransporte);

    const cargo = new Cargo();
    cargo.setIdCargo(idCargo);

    funcionario.setCargo(cargo);

    funcionario.create().then((resultadosBanco) => {
      const resposta = {
        status: true,
        msg: 'Executado com sucesso',
        codigo: '004',
        dados: {
          idFuncionario: resultadosBanco.insertId,
          nome: funcionario.getNome(),
          email: funcionario.getEmail(),
          recebeValeTransporte: funcionario.getRecebeValeTransporte(),
          idCargo: funcionario.getCargo().idCargo
        }
      }
      response.status(200).send(resposta);
    }).catch((erro) => {
      console.error('Error retrieving users:', erro);
    });;

  });


  /**
   * 
   * read
   * 
   */
  app.get('/funcionarios', function (request, response) {

    const funcionario = new Funcionario(banco);

    funcionario.read().then((resultadosBanco) => {

      const resposta = {
        status: true,
        msg: 'Executado com sucesso',
        dados: resultadosBanco
      };

      response.status(200).send(resposta);
    }).catch((erro) => {
      const resposta = {
        status: false,
        msg: 'erro ao executar',
        dados: erro
      };
      response.status(200).send(resposta);

    });;
  });


  app.get('/funcionarios/:id/', (request, response) => {

    const funcionario = new Funcionario(banco);

    const idFuncionario = request.params.id;
    funcionario.setIdFuncionario(idFuncionario);
    funcionario.read().then((resultadosBanco) => {
      const resposta = {
        status: true,
        msg: 'executado com sucesso',
        dados: resultadosBanco
      };
      response.status(200).send(resposta);
    }).catch((erro) => {

      const resposta = {
        status: false,
        msg: 'erro ao executar',
        codigo: '005',
        dados: erro,
      }
      response.status(200).send(resposta);

    });;

  });
  /**
   * update
   */
  app.put('/funcionarios/:id', (request, response) => {

    const idFuncionario = request.params.id;

    const nome = request.body.nome;
    const email = request.body.email;
    const senha = request.body.senha;
    const recebeValeTransporte = request.body.vt;
    const idCargo = request.body.idCargo;


    const funcionario = new Funcionario(banco);

    funcionario.setIdFuncionario(idFuncionario);
    funcionario.setNome(nome);
    funcionario.setEmail(email);
    funcionario.setSenha(senha);
    funcionario.setRecebeValeTransporte(recebeValeTransporte);

    const cargo = new Cargo();
    cargo.setIdCargo(idCargo);

    funcionario.setCargo(cargo);

    funcionario.update().then((resultadosBanco) => {
      const resposta = {
        status: true,
        msg: 'Executado com sucesso',
        codigo: '004',
        dados: {
          idFuncionario: funcionario.getIdFuncionario(),
          nome: funcionario.getNome(),
          email: funcionario.getEmail(),
          recebeValeTransporte: funcionario.getRecebeValeTransporte(),
          idCargo: funcionario.getCargo().idCargo
        }
      }
      response.status(200).send(resposta);
    }).catch((erro) => {
      console.error('Error retrieving users:', erro);
    });;

  });


  /**
   * delete
   */
  app.delete('/funcionarios/:id', (request, response) => {

    const idFuncionario = request.params.id;
    const funcionario = new Funcionario(banco);
    funcionario.setIdFuncionario(idFuncionario);

    funcionario.delete().then((resultadosBanco) => {
      const resposta = {
        status: true,
        msg: 'Excluido com sucesso',
        codigo: '004',
        dados: {
          idFuncionario: funcionario.getIdFuncionario(),
        }
      }
      response.status(200).send(resposta);
    }).catch((erro) => {
      console.error('Error retrieving users:', erro);
    });;

  });
};